:: Jazz RepoTools Launcher
@echo off
rem *******************************************************************************
rem  Licensed Materials - Property of IBM
rem  (c) Copyright IBM Corporation 2006, 2014. All Rights Reserved.
rem  
rem  Note to U.S. Government Users Restricted Rights:  
rem  Use, duplication or disclosure restricted by GSA ADP Schedule 
rem  Contract with IBM Corp. 
rem  *******************************************************************************

setlocal
set RC=0
set START_DIR=%~dp0
set SCRIPT_NAME=%~n0

rem Convert the current working directory
rem to a format that is valid for use in a
rem a file URL
set CUR_PATH=%cd%
set DRIVE=%cd:~0,1%
set SHORT_PATH=%~sp0%
set SHORT_PATH=%SHORT_PATH:\=/%
set PATH_URL=%DRIVE%%%3a%SHORT_PATH%

if NOT "%JAZZ_CONTEXT_PATH%" == "" goto :after_jcp
set JAZZ_CONTEXT_PATH=jazz
:after_jcp

if NOT "%JAZZ_PROVISION_PROFILES%" == "" goto :after_jpp
set JAZZ_PROVISION_PROFILES=%START_DIR%conf\%JAZZ_CONTEXT_PATH%\provision_profiles
:after_jpp

IF EXIST "%JAZZ_PROVISION_PROFILES%" goto :after_exist
echo Could not find provisioning directory %JAZZ_PROVISION_PROFILES%.  If you have moved or renamed your configuration directory, you can use the environment variable JAZZ_PROVISION_PROFILES to point to its new location.
set RC=1
goto :done
:after_exist

set DEFINE=%DEFINE_INIT%
set DEFINE=%DEFINE% "-Dcom.ibm.team.repotools.rcp.scriptName=%SCRIPT_NAME%"
set DEFINE=%DEFINE% "-Dcom.ibm.team.repository.provision.profile=%JAZZ_PROVISION_PROFILES%"
set DEFINE=%DEFINE% "-Dcom.ibm.team.repository.provision.context.path=%JAZZ_CONTEXT_PATH%"
set DEFINE=%DEFINE% -Dorg.eclipse.emf.ecore.plugin.EcorePlugin.doNotLoadResourcesPlugin=true
set DEFINE=%DEFINE% -Djava.awt.headless=true
set DEFINE=%DEFINE% "-DJAZZ_HOME=file:///%PATH_URL%conf"
set DEFINE=%DEFINE% "-Dlog4j.configuration=file:///%PATH_URL%conf/startup_log4j.properties"
set DEFINE=%DEFINE% "-Dcom.ibm.team.migration.ignoreDataMigrationHandlerNotPresentForComponents="
set DEFINE=%DEFINE% "-Dcom.ibm.team.repository.provision.bundle.resolve.only=true"
rem set DEFINE=%DEFINE% -Dcom.ibm.team.repotools.rcp.allowInvalidBundles=true

rem Patch service options.
rem set DEFINE=%DEFINE% -Dcom.ibm.team.osgi.patch.disable=true
rem set DEFINE=%DEFINE% -Dcom.ibm.team.osgi.patch.directory=patch
rem set DEFINE=%DEFINE% -Dcom.ibm.team.osgi.patch.allowConflictingFiles=true
rem set DEFINE=%DEFINE% -Dcom.ibm.team.osgi.patch.skipVersionChecking=true
set DEFINE=%DEFINE% -Dcom.ibm.team.osgi.patch.logLevel=WARNING

rem Comment out the following to allow repotools to run on a server that reports
rem corrupted package names (CRJAZ0179I) 
set DEFINE=%DEFINE% "-Dcom.ibm.team.repository.marshal.tolerance=false"

rem The following four environment variables are used to point to the
rem appropriate JDBC jar file supplied by the database vendor.  For Oracle and
rem SQL Server, the environment variable should point to the driver file itself;
rem for db2i and db2z, the variable should point to the directory that contains 
rem the multiple necessary jdbc driver files required on those platforms. 
rem For db2, the use of DB2_ABSPATH is optional; if not specified, the default 
rem driver installed with server will be used.

rem Users should set these variables; if they are set, the script will respect
rem their value.  If they are unset, we try locating the driver files in a
rem directory under <JazzInstallDir>/server.  (For example, the default location
rem for the Oracle JDBC driver is under
rem <JazzInstallDir>/server/oracle/ojdbc6.jar).

rem Do not use double quotes when you define your environment variable.  If
rem you're setting it from the command line, do:
rem set ORACLE_ABSPATH=c:\path name
rem not:
rem set ORACLE_ABSPATH="c:\path name"

if "%ORACLE_JDBC_DRIVER_FILE%"=="" goto :default_oracle
set DEFINE=%DEFINE% -DORACLE_JDBC_DRIVER_FILE="%ORACLE_JDBC_DRIVER_FILE%"
goto :after_oracle
:default_oracle
set DEFINE=%DEFINE% -DORACLE_JDBC_DRIVER_FILE="%START_DIR%oracle\ojdbc6.jar"
:after_oracle

if "%SQLSERVER_JDBC_DRIVER_FILE%"=="" goto :default_sqlserver
set DEFINE=%DEFINE% -DSQLSERVER_JDBC_DRIVER_FILE="%SQLSERVER_JDBC_DRIVER_FILE%"
goto :after_sqlserver
:default_sqlserver
set DEFINE=%DEFINE% -DSQLSERVER_JDBC_DRIVER_FILE="%START_DIR%sqlserver\sqljdbc4.jar"
:after_sqlserver

if "%DB2I_ABSPATH%"=="" goto :default_db2i
set DEFINE=%DEFINE% -DDB2I_JDBC="%DB2I_ABSPATH%"
goto :after_db2i
:default_db2i
set DEFINE=%DEFINE% -DDB2I_JDBC="%START_DIR%db2i"
:after_db2i

if "%DB2Z_ABSPATH%"=="" goto :default_db2z
set DEFINE=%DEFINE% -DDB2Z_JDBC="%DB2Z_ABSPATH%"
goto :after_db2z
:default_db2z
set DEFINE=%DEFINE% -DDB2Z_JDBC="%START_DIR%db2z"
:after_db2z

if "%DB2_ABSPATH%"=="" goto :after_db2
set DEFINE=%DEFINE% -DDB2_ABSPATH="%DB2_ABSPATH%/"
:after_db2

set VMARGS=
if "%REPOTOOLS_MX_SIZE%"=="" goto :default_mx_size
set VMARGS=%VMARGS% -Xmx%REPOTOOLS_MX_SIZE%M
goto after_mx_size
:default_mx_size
set VMARGS=%VMARGS% -Xmx1500M
:after_mx_size

set VMARGS=%VMARGS% -Xjit:exclude={org.apache.xerces.parsers.AbstractSAXParser.*}
rem set VMARGS=%VMARGS% -Xgcpolicy:gencon
rem set VMARGS=%VMARGS% -Xrunjdwp:transport=dt_socket,server=y,suspend=y,address=localhost:8888

set JAVA="%START_DIR%jre\bin\java"
set LAUNCHER=org.eclipse.equinox.launcher_1.1.1.R36x_v20101122_1400.jar
set JAR="%START_DIR%..\repotools\eclipse\plugins\%LAUNCHER%"
set APPLICATION=com.ibm.team.repotools.rcp.repotools_application
set CONFIGURATION="%START_DIR%conf\%JAZZ_CONTEXT_PATH%\repotools\eclipse\configuration"
set WORKSPACE="%START_DIR%conf\%JAZZ_CONTEXT_PATH%\repotools\workspace"

%JAVA% %VMARGS% %DEFINE% -jar %JAR% -application %APPLICATION% -configuration %CONFIGURATION% -data %WORKSPACE% %*
set RC=%ERRORLEVEL%

:done
endlocal & exit /b %RC%
